;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "enhanced-evil-paredit" "20251016.1351"
  "Paredit support for evil keybindings."
  '((emacs   "24.1")
    (evil    "1.0.9")
    (paredit "25beta"))
  :url "https://github.com/jamescherti/enhanced-evil-paredit.el"
  :commit "58f607ded07383cd6db5a6a39cc0f76dea61c4f7"
  :revdesc "58f607ded073"
  :keywords '("convenience"))
